@@ -25,7 +25,7 @@ except:
     pass
 
 
-version = VERSION = __version__ = '2.0.6'
+version = VERSION = __version__ = '2.0.9'
 
 COLOR = True
 
@@ -205,6 +205,7 @@ def main(*argv, **kwargs):
     basics.add_argument('--flags', '-F', nargs="*", default=None, help="Flag these uploaded files with custom labels")
     basics.add_argument('--env', '-e', nargs="*", default=None, help="Store environment variables to help distinguish CI builds.")
     basics.add_argument('--required', action="store_true", default=False, help="If Codecov fails it will exit 1: failing the CI build.")
+    basics.add_argument('--name', '-n', default=None, help="Custom defined name of the upload. Visible in Codecov UI.")
 
     gcov = parser.add_argument_group('======================== gcov ========================')
     gcov.add_argument('--gcov-root', default=None, help="Project root directory when preparing gcov")
@@ -245,8 +246,10 @@ def main(*argv, **kwargs):
 
     # add from cli
     if codecov.env:
+        # -e VAR1,VAR2 or -e VAR1 -e VAR2
         for env in codecov.env:
-            include_env.add(env.strip())
+            for e in env.split(','):
+                include_env.add(e.strip())
 
     # add from env
     if os.getenv("CODECOV_ENV"):
@@ -274,10 +277,10 @@ def main(*argv, **kwargs):
         if os.getenv('JENKINS_URL'):
             # https://wiki.jenkins-ci.org/display/JENKINS/Building+a+software+project
             # https://wiki.jenkins-ci.org/display/JENKINS/GitHub+pull+request+builder+plugin#GitHubpullrequestbuilderplugin-EnvironmentVariables
-            query.update(dict(branch=os.getenv('ghprbSourceBranch') or os.getenv('GIT_BRANCH'),
+            query.update(dict(branch=os.getenv('ghprbSourceBranch') or os.getenv('GIT_BRANCH') or os.getenv('BRANCH_NAME'),
                               service='jenkins',
                               commit=os.getenv('ghprbActualCommit') or os.getenv('GIT_COMMIT'),
-                              pr=os.getenv('ghprbPullId', 'false'),
+                              pr=os.getenv('ghprbPullId') or os.getenv('CHANGE_ID'),
                               build=os.getenv('BUILD_NUMBER'),
                               build_url=os.getenv('BUILD_URL')))
             root = os.getenv('WORKSPACE') or root
@@ -304,7 +307,7 @@ def main(*argv, **kwargs):
 
             _add_env_if_not_empty(include_env, 'TRAVIS_OS_NAME')
             if language:
-                _add_env_if_not_empty(include_env, 'TRAVIS_%s_NAME' % language.upper())
+                _add_env_if_not_empty(include_env, 'TRAVIS_%s_VERSION' % language.upper())
 
         # --------
         # Codeship
@@ -405,6 +408,7 @@ def main(*argv, **kwargs):
                               slug=os.getenv('APPVEYOR_REPO_NAME'),
                               commit=os.getenv('APPVEYOR_REPO_COMMIT')))
             write('    AppVeyor Detected')
+            codecov.disable.append('search')
 
         # -------
         # Wercker
@@ -466,13 +470,17 @@ def main(*argv, **kwargs):
             query.update(dict(service='gitlab',
                               branch=os.getenv('CI_BUILD_REF_NAME'),
                               build=os.getenv('CI_BUILD_ID'),
-                              slug=os.getenv('CI_BUILD_REPO').split('/', 3)[-1].replace('.git', ''),
                               commit=os.getenv('CI_BUILD_REF')))
             if os.getenv('CI_PROJECT_DIR', '').startswith('/'):
                 root = os.getenv('CI_PROJECT_DIR')
             else:
                 root = os.getenv('HOME') + '/' + os.getenv('CI_PROJECT_DIR', '')
 
+            if os.getenv('CI_BUILD_REPO'):
+                query['slug'] = os.getenv('CI_BUILD_REPO').split('/', 3)[-1].replace('.git', '')
+            elif os.getenv('CI_REPOSITORY_URL'):
+                query['slug'] = os.getenv('CI_REPOSITORY_URL').split('/', 3)[-1].replace('.git', '')
+
             write('    Gitlab CI Detected')
 
         else:
@@ -506,6 +514,9 @@ def main(*argv, **kwargs):
 
     # Update Query
     # ------------
+    if codecov.name:
+        query['name'] = codecov.name
+
     if codecov.flags:
         query['flags'] = ','.join(codecov.flags)
 
@@ -549,7 +560,6 @@ def main(*argv, **kwargs):
             query['token'] = fopen(opj(os.getcwd(), query['token'][1:])).strip()
 
         assert query.get('commit') not in ('', None), "Commit sha is missing. Please specify via --commit=:sha"
-        assert query.get('job') or query.get('token'), "Missing repository upload token"
 
         # Build TOC
         # ---------
@@ -559,25 +569,34 @@ def main(*argv, **kwargs):
                    try_to_run('hg locate') or '').strip())
 
         # Detect codecov.yml location
-        for _filename in toc.splitlines():
-            if _filename in ('codecov.yml', '.codecov.yml') or _filename.endswith(('/codecov.yml', '/.codecov.yml')):
-                query['yaml'] = _filename
-                # from yaml import load
-                # ccyaml = load(fopen(_filename)).get('codecov')
-                # if ccyaml and type(ccyaml) is dict:
-                #     if ccyaml.get('token'):
-                #         write('    Set token from yaml')
-                #         query['token'] = ccyaml.get('token')
+        yaml_location = re.search(
+            r'\.?codecov\.ya?ml$',
+            toc,
+            re.M
+        )
+        if yaml_location:
+            yaml_location = yaml_location.group()
+            yaml_path = opj(root, yaml_location)
+            if os.path.exists(yaml_path):
+                query['yaml'] = yaml_location
+                yaml = fopen(yaml_path)
+                _token = re.search(
+                    r'token: (\'|\")?([0-9a-f]{8}(-?[0-9a-f]{4}){3}-?[0-9a-f]{12})',
+                    yaml,
+                    re.M
+                )
+                if _token:
+                    query['token'] = _token.groups()[1]
 
-                #     if ccyaml.get('url'):
-                #         write('    Set url from yaml')
-                #         codecov.url = ccyaml.get('url')
+                _slug = re.search(
+                    r'slug: (\'|\")?([\w\-\.\+]+\/[\w\-\.\+]+)',
+                    yaml,
+                    re.M
+                )
+                if _slug:
+                    query['slug'] = _slug.groups()[1]
 
-                #     if ccyaml.get('slug'):
-                #         write('    Set slug from yaml')
-                #         codecov.slug = ccyaml.get('slug')
-
-                break
+        assert query.get('job') or query.get('token'), "Missing repository upload token"
 
         # Processing gcov
         # ---------------
@@ -586,21 +605,6 @@ def main(*argv, **kwargs):
 
         else:
             write('==> Processing gcov (disable by -X gcov)')
-            if os.path.isdir(os.path.expanduser('~/Library/Developer/Xcode/DerivedData')):
-                write('WARNING: Depreciating Xcode support in python uploader. Please use Bash uploader: https://github.com/codecov/codecov-bash')
-                write('    Found OSX DerivedData')
-                try_to_run("find ~/Library/Developer/Xcode/DerivedData -name '*.gcda' -exec gcov -pb {} +")
-
-                # xcode7
-                profdata = try_to_run("find ~/Library/Developer/Xcode/DerivedData -name 'Coverage.profdata' | head -1")
-                if profdata:
-                    _dir = os.path.dirname(profdata)
-                    for _type in ('app', 'framework', 'xctest'):
-                        _file = try_to_run('find "%s" -name "*.%s" | head -1' % (_dir, _type))
-                        if _file:
-                            _proj = _file.split('/')[-2].split('.')[0]
-                            try_to_run('xcrun llvm-cov show -instr-profile "%s" "%s/%s" > "%s.coverage.txt"' % (profdata, _file, _proj, _type))
-
             cmd = "find %s -type f -name '*.gcno' %s -exec %s -pb %s {} +" % (
                   (codecov.gcov_root or root),
                   " ".join(map(lambda a: "-not -path '%s'" % a, codecov.gcov_glob)),
